
# Apyrat ![download badge](.pypi_chart/badge.svg)

![PyPI releases](https://img.shields.io/pypi/v/apyrat?logo=python&logoColor=white)
![Python Versions](https://img.shields.io/pypi/pyversions/apyrat.svg)
![MIT License](https://img.shields.io/github/license/CodeWithEmad/apyrat.svg?style=flat-square)

Yet another [Aparat](https://www.aparat.com) video downloader.

## Getting Started

you can install Apyrat from PyPi:

``` bash
pip install -U apyrat
```

for example you want to download the video hosted [here](https://www.aparat.com/v/qur3I). Just run:

``` bash
apyrat https://www.aparat.com/v/qur3I
```

you can also download playlists:

``` bash
apyrat https://www.aparat.com/playlist/448747
```

## Contributing

Any contributions are welcome here! To learn how you can contribute, please check the [contributing doc](https://github.com/CodeWithEmad/apyrat/blob/master/CONTRIBUTING.md).

## License

This work is licensed under the terms of the [MIT](https://github.com/CodeWithEmad/apyrat/blob/master/LICENSE).
